@@ -1,7 +1,7 @@
 from django.contrib import admin
 
 # Register your models here.
-from apps.csv_importer.models import CSVUploadModel
+from csv_importer.models import CSVUploadModel
 
 
 class CsvUploadAdmin(admin.ModelAdmin):
